Index: samples/github/ios/compile.sh |
diff --git a/samples/github/ios/compile.sh b/samples/github/ios/compile.sh |
index 29fc30d822859046f02de8dc7a8a7a6811c54c2a..8f077540673dd6641548a8c6f9ae4d6bd39dd6f4 100755 |
--- a/samples/github/ios/compile.sh |
+++ b/samples/github/ios/compile.sh |
@@ -5,19 +5,19 @@ |
# BSD-style license that can be found in the LICENSE.md file. |
# Setup |
# - Install and build fletch. |
# - Install Cocoapods. |
# - Run immic (output in generated/packages/immi). |
# - Run servicec (output in generated/packages/service). |
# - Generate libfletch.a for your choice of platforms and add it to xcode. |
# - Generate snapshot of your Dart program and add it to xcode. |
# - Write Podfile that links to {Fletch,Service,Immi}.podspec. |
# - Run pod install. |
# Build (implemented by the present script). |
# - Run immic. |
# - Run servicec. |
-# - Generate libfletch. |
+# - Generate libdartino. |
# - Generate snapshot of your Dart program. |
# After this, hit the 'run' button in xcode. |
@@ -26,8 +26,8 @@ set -ue |
DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)" |
PROJ=github |
-FLETCH_DIR="$(cd "$DIR/../../.." && pwd)" |
-FLETCH_PKG_DIR="$FLETCH_DIR/package" |
+DARTINO_DIR="$(cd "$DIR/../../.." && pwd)" |
+DARTINO_PKG_DIR="$DARTINO_DIR/package" |
TARGET_DIR="$(cd "$DIR/.." && pwd)" |
TARGET_GEN_DIR="$TARGET_DIR/generated" |
@@ -36,16 +36,16 @@ TARGET_PKG_FILE="$TARGET_DIR/.packages" |
IMMI_GEN_DIR="$TARGET_GEN_DIR/immi" |
SERVICE_GEN_DIR="$TARGET_GEN_DIR/service" |
-DART="$FLETCH_DIR/out/ReleaseIA32/dart" |
-IMMIC="$DART $FLETCH_DIR/tools/immic/bin/immic.dart" |
-FLETCH="$FLETCH_DIR/out/ReleaseIA32/fletch" |
-SERVICEC="$FLETCH x-servicec" |
+DART="$DARTINO_DIR/out/ReleaseIA32/dart" |
+IMMIC="$DART $DARTINO_DIR/tools/immic/bin/immic.dart" |
+DARTINO="$DARTINO_DIR/out/ReleaseIA32/dartino" |
+SERVICEC="$DARTINO x-servicec" |
MOCK_SERVER_SNAPSHOT="$TARGET_DIR/github_mock_service.snapshot" |
set -x |
-cd $FLETCH_DIR |
+cd $DARTINO_DIR |
ninja -C out/ReleaseIA32 |
@@ -65,19 +65,19 @@ if [[ $# -eq 0 ]] || [[ "$1" == "immi" ]]; then |
$DIR/../compile_mock_service.sh service |
fi |
-if [[ $# -eq 0 ]] || [[ "$1" == "fletch" ]]; then |
- ninja -C out/ReleaseIA32IOS libfletch.a |
- ninja -C out/ReleaseXARM libfletch.a |
- lipo -create -output "$DIR/libfletchvm.a" \ |
- out/ReleaseIA32IOS/libfletch.a \ |
- out/ReleaseXARM/libfletch.a |
+if [[ $# -eq 0 ]] || [[ "$1" == "dartino" ]]; then |
+ ninja -C out/ReleaseIA32IOS libdartino.a |
+ ninja -C out/ReleaseXARM libdartino.a |
+ lipo -create -output "$DIR/libdartinovm.a" \ |
+ out/ReleaseIA32IOS/libdartino.a \ |
+ out/ReleaseXARM/libdartino.a |
fi |
if [[ $# -eq 0 ]] || [[ "$1" == "snapshot" ]]; then |
$DART -c --packages=.packages \ |
-Dsnapshot="$DIR/$PROJ.snapshot" \ |
-Dpackages="$TARGET_PKG_FILE" \ |
- tests/fletchc/run.dart "$TARGET_DIR/bin/$PROJ.dart" |
+ tests/dartino_compiler/run.dart "$TARGET_DIR/bin/$PROJ.dart" |
fi |
# Ensure that we have a mock server. |
@@ -90,6 +90,6 @@ set +x |
if [[ $# -eq 1 ]]; then |
echo |
echo "Only ran task $1." |
- echo "Possible tasks: immi, fletch, and snapshot" |
- echo "If Fletch or any IMMI files changed re-run compile.sh without arguments." |
+ echo "Possible tasks: immi, dartino, and snapshot" |
+ echo "If Dartino or any IMMI files changed re-run compile.sh without arguments." |
fi |
@@ -5,19 +5,19 @@ |
# BSD-style license that can be found in the LICENSE.md file. |
# Setup |
-# - Install and build fletch. |
+# - Install and build dartino. |
# - Install Cocoapods. |
# - Run immic (output in generated/packages/immi). |
@@ -5,19 +5,19 @@ |
# - Run immic (output in generated/packages/immi). |
# - Run servicec (output in generated/packages/service). |
-# - Generate libfletch.a for your choice of platforms and add it to xcode. |
+# - Generate libdartino.a for your choice of platforms and add it to xcode. |
# - Generate snapshot of your Dart program and add it to xcode. |
@@ -5,19 +5,19 @@ |
# - Generate snapshot of your Dart program and add it to xcode. |
-# - Write Podfile that links to {Fletch,Service,Immi}.podspec. |
+# - Write Podfile that links to {Dartino,Service,Immi}.podspec. |
# - Run pod install. |
# Build (implemented by the present script). |